==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/FunnelDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelDataContextDescription } from "./FunnelDataContextDescription";
/**
 * @hidden
 */
var FunnelDataContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FunnelDataContextDescriptionMetadata, _super);
    function FunnelDataContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelDataContextDescriptionMetadata.b = function (a) {
        if (FunnelDataContextDescriptionMetadata.a == null) {
            FunnelDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelDataContextDescriptionMetadata.c(FunnelDataContextDescriptionMetadata.a);
        }
        if (a.k(FunnelDataContextDescriptionMetadata.a)) {
            return;
        }
        a.ab(FunnelDataContextDescriptionMetadata.a);
    };
    FunnelDataContextDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("Index", "Number:int");
    };
    FunnelDataContextDescriptionMetadata.d = function (a) {
        FunnelDataContextDescriptionMetadata.b(a);
        a.ad("FunnelDataContext", function () { return new FunnelDataContextDescription(); });
        a.ac("FunnelDataContext", FunnelDataContextDescriptionMetadata.a);
    };
    FunnelDataContextDescriptionMetadata.$t = markType(FunnelDataContextDescriptionMetadata, 'FunnelDataContextDescriptionMetadata');
    FunnelDataContextDescriptionMetadata.a = null;
    return FunnelDataContextDescriptionMetadata;
}(Base));
export { FunnelDataContextDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/FunnelDataContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FunnelDataContextDescription } from "./FunnelDataContextDescription";
/**
 * @hidden
 */
var FunnelDataContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FunnelDataContextDescriptionMetadata, _super);
    function FunnelDataContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FunnelDataContextDescriptionMetadata.b = function (a) {
        if (FunnelDataContextDescriptionMetadata.a == null) {
            FunnelDataContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FunnelDataContextDescriptionMetadata.c(FunnelDataContextDescriptionMetadata.a);
        }
        if (a.k(FunnelDataContextDescriptionMetadata.a)) {
            return;
        }
        a.ac(FunnelDataContextDescriptionMetadata.a);
    };
    FunnelDataContextDescriptionMetadata.c = function (a) {
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("Index", "Number:int");
    };
    FunnelDataContextDescriptionMetadata.d = function (a) {
        FunnelDataContextDescriptionMetadata.b(a);
        a.ae("FunnelDataContext", function () { return new FunnelDataContextDescription(); });
        a.ad("FunnelDataContext", FunnelDataContextDescriptionMetadata.a);
    };
    FunnelDataContextDescriptionMetadata.$t = markType(FunnelDataContextDescriptionMetadata, 'FunnelDataContextDescriptionMetadata');
    FunnelDataContextDescriptionMetadata.a = null;
    return FunnelDataContextDescriptionMetadata;
}(Base));
export { FunnelDataContextDescriptionMetadata };
